# New in 0.12.1 (2021-07-29)

## Changes

-   Update Pytorch Lightning version dependency to `>=1.3,<1.4` ([#1104]).

## Breaking changes

None!

## Contributors

-   [@adamgayoso]
-   [@galenxing]

[#1104]: https://github.com/YosefLab/scvi-tools/pull/1104
[@adamgayoso]: https://github.com/adamgayoso
[@galenxing]: https://github.com/galenxing
